@@ -1,11 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the toplevel of this
 # repository contains the full copyright notices and license terms.
-from ..pool import Pool
+from trytond.pool import Pool
 from .model import Model
 from .match import MatchMixin
 
 
 class MultiValueMixin(object):
+    __slots__ = ()
 
     @classmethod
     def multivalue_model(cls, field):
@@ -17,7 +18,7 @@ class MultiValueMixin(object):
 
     def multivalue_records(self, field):
         Value = self.multivalue_model(field)
-        for fname, field in self._fields.iteritems():
+        for fname, field in self._fields.items():
             if (field._type == 'one2many'
                     and field.model_name == Value.__name__):
                 return getattr(self, fname)
@@ -25,7 +26,7 @@ class MultiValueMixin(object):
 
     def multivalue_record(self, field, **pattern):
         Value = self.multivalue_model(field)
-        for fname, field in Value._fields.iteritems():
+        for fname, field in Value._fields.items():
             if (field._type == 'many2one'
                     and field.model_name == self.__name__):
                 pattern = pattern.copy()
@@ -59,7 +60,7 @@ class MultiValueMixin(object):
                 return str(value)
             return value.id
         elif isinstance(value, (list, tuple)):
-            return [r.id for r in value]
+            return tuple(r.id if isinstance(r, Model) else r for r in value)
         else:
             return value
 
@@ -92,4 +93,4 @@ class ValueMixin(MatchMixin):
 
 
 def filter_pattern(pattern, Value):
-    return {f: v for f, v in pattern.iteritems() if f in Value._fields}
+    return {f: v for f, v in pattern.items() if f in Value._fields}
